@@ -14,7 +14,7 @@ import inspect
 
 # ========================================================================== #
 def fit_bdata(data, fn, omit=None, rebin=None, shared=None, hist_select='',
-              xlims=None, asym_mode='c', fixed=None, minimizer='migrad+minos', **kwargs):
+              xlims=None, asym_mode='c', fixed=None, minimizer='migrad', **kwargs):
     """
         Fit combined asymetry from bdata.
     
@@ -57,7 +57,7 @@ def fit_bdata(data, fn, omit=None, rebin=None, shared=None, hist_select='',
                         parameters omitted. Can be a list of lists with one list 
                         for each run.
                         
-        minimizer       string. One of "migrad", "trf", "dogbox"
+        minimizer       string. One of "migrad", "minos", "trf", "dogbox"
         
         kwargs:         keyword arguments for curve_fit/minuit. 
                         See curve_fit/iminuit docs. 
@@ -114,9 +114,6 @@ def fit_bdata(data, fn, omit=None, rebin=None, shared=None, hist_select='',
     # fit globally -----------------------------------------------------------
     if any(shared) and ndata>1:
         print('Running shared parameter fitting... ', flush=True)
-        do_minos = 'minos' in minimizer
-        minimizer = 'migrad' if 'migrad' in minimizer else minimizer
-            
         g = global_bdata_fitter(data = data, 
                                 fn = fn, 
                                 xlims = xlims,
@@ -126,7 +123,7 @@ def fit_bdata(data, fn, omit=None, rebin=None, shared=None, hist_select='',
                                 fixed = fixed,
                                 )
                                 
-        g.fit(minimizer=minimizer, do_minos=do_minos, **kwargs)
+        g.fit(minimizer=minimizer, **kwargs)
         gchi, chis = g.get_chi() # returns global chi, individual chi squared
         pars, stds_l, stds_h, covs = g.get_par()
         
@@ -210,8 +207,7 @@ def fit_bdata(data, fn, omit=None, rebin=None, shared=None, hist_select='',
                                     
                 # check minuit validity
                 if m is not None: 
-                    
-                    
+                       
                     if not all((m.fmin.is_valid, 
                                 m.fmin.has_valid_parameters,
                                 not m.fmin.hesse_failed,
@@ -222,14 +218,20 @@ def fit_bdata(data, fn, omit=None, rebin=None, shared=None, hist_select='',
                                 not m.fmin.has_reached_call_limit,
                                 not m.fmin.is_above_max_edm,                                
                                 )):
-                                    
-                        msg = ('====== %d.%d ======\n' % (d.year, d.run),
+                        
+                        try: 
+                            msg = ('====== %d.%d ======\n' % (d.year, d.run),
                                str(m.fmin), '\n',
                                str(m.params), '\n',
                                )
                                
-                        iter_obj.write(''.join(msg))
-                    
+                            iter_obj.write(''.join(msg))
+                        except UnicodeEncodeError:
+                            msg = ('====== %d.%d ======\n' % (d.year, d.run),
+                               repr(m.fmin), '\n',
+                               repr(m.params), '\n',
+                               )
+                            iter_obj.write(''.join(msg))
                     
             # outputs
             pars.append(p)
@@ -261,7 +263,7 @@ def fit_bdata(data, fn, omit=None, rebin=None, shared=None, hist_select='',
 
 # =========================================================================== #
 def _fit_single(data,fn,omit='',rebin=1,hist_select='',xlim=None,asym_mode='c',
-               fixed=None, minimizer='migrad+minos', **kwargs):
+               fixed=None, minimizer='migrad', **kwargs):
     """
         Fit combined asymetry from bdata.
     
@@ -293,7 +295,7 @@ def _fit_single(data,fn,omit='',rebin=1,hist_select='',xlim=None,asym_mode='c',
                         parameters in order presented, with the fixed 
                         parameters omitted.
                         
-        minimizer       string. One of "migrad", "trf", "dogbox"
+        minimizer       string. One of "migrad", "minos", "trf", "dogbox"
         
         kwargs:         keyword arguments for curve_fit. See curve_fit docs. 
         
@@ -328,7 +330,7 @@ def _fit_single(data,fn,omit='',rebin=1,hist_select='',xlim=None,asym_mode='c',
         kwargs['p0'] = np.ones(nargs)
     
     # Fit the function
-    if "migrad" in minimizer:
+    if minimizer in ("migrad", "minos"):
         par, cov, stdl, stdh, chi, m = _fit_single_minuit(fn, x, y, dy, fixed, 
                                                           'minos' in minimizer, 
                                                           **kwargs)
@@ -370,8 +372,13 @@ def _fit_single_minuit(fn, x, y, dy, fixed, do_minos=True, **kwargs):
     m.migrad()
     
     if do_minos:
-        m.minos()
-        lower, upper = m.np_merrors()
+        try:
+            m.minos()
+            lower, upper = m.np_merrors()
+        except RuntimeError as errmsg: # migrad did not converge
+            print(errmsg)
+            err = m.np_errors()
+            lower, upper = (err, err)
     else:
         m.hesse()
         err = m.np_errors()
@@ -379,7 +386,11 @@ def _fit_single_minuit(fn, x, y, dy, fixed, do_minos=True, **kwargs):
     
     # get parameters
     par = m.np_values()
-    cov = m.np_covariance()
+    
+    try:
+        cov = m.np_covariance()
+    except RuntimeError:
+        cov = None
     
     dof = len(y) - len(kwargs['p0'])
     chi = m.fval/dof
